# services/review_adder.py

from langchain_community.docstore.document import Document
from reviewsense.core.config import get_settings
from langchain_huggingface import HuggingFaceEmbeddings
from langchain_astradb import AstraDBVectorStore

class ReviewAdder:
    """Class for adding reviews to the vector store"""

    def __init__(self, collection_name: str, embedding_model: str):
        settings = get_settings()
        self.embeddings = HuggingFaceEmbeddings(model_name=embedding_model)
        self.vector_store = AstraDBVectorStore(
            collection_name=collection_name,
            embedding=self.embeddings,
            api_endpoint=settings.ASTRA_DB_API_ENDPOINT,
            token=settings.ASTRA_DB_APPLICATION_TOKEN,
            namespace=settings.ASTRA_DB_NAMESPACE,
        )

    def add_review(self, product_id: str, review: str) -> str:
        review_document = Document(page_content=review, metadata={"title": product_id})
        return self.vector_store.add_documents([review_document])[0]
