# services/review_fetcher.py

from typing import List, Dict
from reviewsense.core.config import get_settings
from langchain_astradb import AstraDBVectorStore
from langchain_huggingface import HuggingFaceEmbeddings

class ReviewFetcher:
    """Class for fetching reviews from the vector store"""

    def __init__(self, collection_name: str, embedding_model: str):
        settings = get_settings()
        self.embeddings = HuggingFaceEmbeddings(model_name=embedding_model)
        self.vector_store = AstraDBVectorStore(
            collection_name=collection_name,
            embedding=self.embeddings,
            api_endpoint=settings.ASTRA_DB_API_ENDPOINT,
            token=settings.ASTRA_DB_APPLICATION_TOKEN,
            namespace=settings.ASTRA_DB_NAMESPACE,
        )

    def fetch_reviews(self, product_id: str, features: List[str], threshold: float = 0.6) -> Dict[str, List[str]]:
        feature_reviews = {}

        for feature in features:
            filter_criteria = {"title": product_id}
            documents = self.vector_store.similarity_search_with_score_id(query=feature, k=100, filter=filter_criteria)

            filtered_reviews = [doc.page_content for doc, score, _ in documents if score > threshold]
            feature_reviews[feature] = filtered_reviews

        return feature_reviews
